/**
 * @package     hubzero-cms
 * @file        plugins/hubzero/imagecaptcha/imagecaptcha.js
 * @copyright   Copyright 2005-2011 Purdue University. All rights reserved.
 * @license     http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
 */

// Ensure we have our namespace
if (!HUB) {
	var HUB = {};
}
if (!HUB.Plugins) {
	HUB.Plugins = {};
}

// Plugin scripts
if (!jq) {
	var jq = $;
}

// Initialize script
jQuery(document).ready(function($){
	// Nothing here yet...
});